@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the Hooktheory API
 
-our $VERSION = '0.0101';
+our $VERSION = '0.02';
 
 use Moo;
 use strictures 2;
@@ -82,7 +82,13 @@ sub _handle_response {
     my $data;
 
     if ( my $res = $tx->success ) {
-        $data = decode_json( $res->body );
+        my $body = $res->body;
+        if ( $body =~ /^{/ && $body =~ /}$/ ) {
+            $data = decode_json( $res->body );
+        }
+        else {
+            croak $body, "\n";
+        }
     }
     else {
         my $err = $tx->error;
@@ -108,7 +114,7 @@ WebService::Hooktheory - Access to the Hooktheory API
 
 =head1 VERSION
 
-version 0.0101
+version 0.02
 
 =head1 SYNOPSIS
 
